gchecky.model.cancel_order_t

Package gchecky :: Module model :: Class cancel_order_t |
[hide private]
[frames] | no frames]

# Class cancel_order_t

source code

    object --+
             |
     gxml.Node --+
                 |
     gxml.Document --+
                     |
      abstract_order_t --+
                         |
                        cancel_order_t

Represents an order that should be canceled. A <cancel-order> command sets the financial-order-state and the fulfillment-order-state to canceled.

    >>> test_document(
    ...     cancel_order_t(google_order_number = "841171949013218",
    ...                    comment = 'Buyer found a better deal.',
    ...                    reason = 'Buyer cancelled the order.'
    ...     )
    ... ,
    ...     '''
    ...     <cancel-order xmlns="http://checkout.google.com/schema/2" google-order-number="841171949013218">
    ...       <comment>Buyer found a better deal.</comment>
    ...       <reason>Buyer cancelled the order.</reason>
    ...     </cancel-order>
    ...     '''
    ... )

Nested Classes | [hide private]
Inherited from `gxml.Document`: `__metaclass__`

Instance Methods | [hide private]
Inherited from `gxml.Document`: `__str__`, `toxml` Inherited from `gxml.Node`: `__eq__`, `__init__`, `__neq__`, `read`, `write` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`

Class Methods | [hide private]
Inherited from `gxml.Document`: `fromxml` Inherited from `gxml.Node`: `fields`, `set_fields`

Static Methods | [hide private]
Inherited from `gxml.Node`: `__new__`

Class Variables | [hide private]
| tag_name = ``'``cancel-order``'`` The document's unique xml tag name.
| comment = `String:PATH(comment):OPT:EMPTY`
| reason = `String:PATH(reason):REQ:EMPTY`
| _fields = ``{``'``comment``'``:` String:PATH(comment):OPT:EMPTY`,` `'``google_``...`` list of meta-Fields of this class.
Inherited from `abstract_order_t`: `google_order_number`

Properties | [hide private]
Inherited from `object`: `__class__`

Class Variable Details | [hide private]

  ### _fields list of meta-Fields of this class. Value:
      {'comment': String:PATH(comment):OPT:EMPTY,
       'google_order_number': ID:PATH(@google-order-number):REQ:EMPTY,
       'reason': String:PATH(reason):REQ:EMPTY}